@@ -14,10 +14,10 @@ if [[ $INSTALL_OPTIONAL != false ]]; then
 	[[ $(command -v sphinx-autogen) == "" ]] && echo "Installing py_sphinx" && extension --install py_sphinx && echo "Finished py_sphinx"
 fi
 
-if [ $BUILD_ALL == "false" ] && [ ! -f /usr/share/ECM/cmake/ECMConfigVersion.cmake ] && [[ $(cat /usr/share/ECM/cmake/ECMConfigVersion.cmake | grep 'set(PACKAGE_VERSION "6.15.0")') == "" ]]; then
+if [[ $BUILD_ALL == "false" ]] && [ ! -f /usr/share/ECM/cmake/ECMConfigVersion.cmake ] && [[ $(cat /usr/share/ECM/cmake/ECMConfigVersion.cmake | grep 'set(PACKAGE_VERSION "6.17.0")') == "" ]]; then
 	echo "extra_cmake_modules" 							>> $EXTENSION/build_order.txt
 fi
-if [ $BUILD_ALL == "true" ]; then
+if [[ $BUILD_ALL == "true" ]]; then
 	echo "extra_cmake_modules" 							>> $EXTENSION/build_order.txt
 fi
 echo "complete _" 										>> $EXTENSION/build_order.txt
